# Yellowbrick 2.0

A fork of Yellowbrick with updates to support recent versions of Matplotlib, NumPy, Scikit-Learn, and Python. This fork also migrates to `pyproject.toml` for package management.

This is designed to be a drop-in replacement for the unmaintained `yellowbrick` package on PyPI.

## Installation

Install with:

```
pip install yellowbrick2
```

Then import as usual:

```
from yellowbrick import ...
```

## Warning

Don't install both this and the original `yellowbrick` package! They conflict because they share the same `yellowbrick` namespace.

PyPI and pip have no mechanism to declare that one package conflicts with another. There's no `conflicts` field in `pyproject.toml`, `setup.cfg`, or the core metadata spec (https://peps.python.org/pep-0566/ and https://peps.python.org/pep-0643/), so we can't easily make `pip` refuse to install both.

If you install both packages, one package will overwrite the other package's files, leading to unpredictable behavior.

## Docs

See the docs [here](https://www.scikit-yb.org/en/latest/index.html)

## Maintainers

Fork maintained by Ed Schofield at [Python Charmers](https://pythoncharmers.com).
